@@ -2,7 +2,7 @@
  * @file encode.c
  *
  * @section LICENSE
- * Copyright 2023 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
+ * Copyright 2025 Mathis Rosenhauer, Moritz Hanke, Joerg Behrens, Luis Kornblueh
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -226,8 +226,8 @@ static void preprocess_unsigned(struct aec_stream *strm)
 
     uint32_t D;
     struct internal_state *state = strm->state;
-    const uint32_t *restrict x = state->data_raw;
-    uint32_t *restrict d = state->data_pp;
+    const uint32_t *x = state->data_raw;
+    uint32_t *d = state->data_pp;
     uint32_t xmax = state->xmax;
     uint32_t rsi = strm->rsi * strm->block_size - 1;
 
@@ -260,8 +260,8 @@ static void preprocess_signed(struct aec_stream *strm)
 
     uint32_t D;
     struct internal_state *state = strm->state;
-    uint32_t *restrict x = state->data_raw;
-    uint32_t *restrict d = state->data_pp;
+    uint32_t *x = state->data_raw;
+    uint32_t *d = state->data_pp;
     uint32_t xmax = state->xmax;
     uint32_t xmin = state->xmin;
     uint32_t rsi = strm->rsi * strm->block_size - 1;
@@ -337,7 +337,7 @@ static uint32_t assess_splitting_option(struct aec_stream *strm)
     struct internal_state *state = strm->state;
 
     /* Block size of current block */
-    int this_bs = strm->block_size - state->ref;
+    uint64_t this_bs = strm->block_size - state->ref;
 
     /* CDS length minimum so far */
     uint64_t len_min = UINT64_MAX;
@@ -890,7 +890,6 @@ int aec_encode_init(struct aec_stream *strm)
     *state->cds = 0;
     state->bits = 8;
     state->mode = m_get_block;
-    struct vector_t *offsets = NULL;
     state->ready_to_capture_rsi = 0;
     return AEC_OK;
 }
